GhostShared

Struct GhostShared 

pub struct GhostShared<T>(/* private fields */);
A type for sharing ghost data immutably.

Implementations

Source

impl<T> GhostShared<T>

pub fn new(val: Ghost<T>) -> Ghost<Self>

Create a new shared ghost value.

Note that the original value can never be retrieved, which allows this function to resolve it (in GhostShared’s type invariant).

terminates

ghost

ensures

result@ == *val

Source

impl<T> GhostShared<T>

pub fn val(self) -> T

The logical value contained in this GhostShared.

logic